@@ -2,6 +2,13 @@ import operator
 
 import pytest
 
+from fletcher import (
+    FletcherChunkedArray,
+    FletcherChunkedDtype,
+    FletcherContinuousArray,
+    FletcherContinuousDtype,
+)
+
 # More information about the pandas extension interface tests can be found here
 # https://github.com/pandas-dev/pandas/blob/master/pandas/tests/extension/base/__init__.py
 
@@ -130,6 +137,22 @@ def fletcher_variant(request):
     return request.param
 
 
+@pytest.fixture
+def fletcher_dtype(fletcher_variant):
+    if fletcher_variant == "chunked":
+        return FletcherChunkedDtype
+    else:
+        return FletcherContinuousDtype
+
+
+@pytest.fixture
+def fletcher_array(fletcher_variant):
+    if fletcher_variant == "chunked":
+        return FletcherChunkedArray
+    else:
+        return FletcherContinuousArray
+
+
 @pytest.fixture(params=["chunked", "continuous"], scope="session")
 def fletcher_variant_2(request):
     """Whether to test the chunked or continuous implementation.
